@@ -11,7 +11,8 @@ our %_URL = (
 	'archconf_expanded'    => '/archconf_expanded.txt',
 	'contentfilter_status' => '/ContentFilter/Status',
 	'sysinfo'              => '/SYSINFO',
-	'send_command'         => '/Secure/Local/console/install_upload_action/cli_post_setup.txt'
+	'send_command' =>
+	  '/Secure/Local/console/install_upload_action/cli_post_setup.txt'
 );
 
 our %defaults = (
@@ -29,11 +30,11 @@ BlueCoat::SGOS - A module to interact with Blue Coat SGOS-based devices.
 
 =head1 VERSION
 
-Version 1.04
+Version 1.05
 
 =cut
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 =head1 SYNOPSIS
 
@@ -114,10 +115,16 @@ sub new {
 		&& $self->{'_appliancepassword'}) {
 
 		if ($self->{'_applianceconnectmode'} eq 'https') {
-			$self->{'_applianceurlbase'} = q#https://# . $self->{'_appliancehost'} . q#:# . $self->{'_applianceport'};
+			$self->{'_applianceurlbase'} =
+			    q#https://#
+			  . $self->{'_appliancehost'} . q#:#
+			  . $self->{'_applianceport'};
 		}
 		elsif ($self->{'_applianceconnectmode'} eq 'http') {
-			$self->{'_applianceurlbase'} = q#http://# . $self->{'_appliancehost'} . q#:# . $self->{'_applianceport'};
+			$self->{'_applianceurlbase'} =
+			    q#http://#
+			  . $self->{'_appliancehost'} . q#:#
+			  . $self->{'_applianceport'};
 		}
 	}
 
@@ -149,17 +156,22 @@ sub get_sysinfo {
 
 	if ($self->{'_debuglevel'} > 0) {
 		print 'URLBASE=' . $self->{'_applianceurlbase'} . "\n";
-		print 'Getting ' . $self->{'_applianceurlbase'} . $_URL{'sysinfo'} . "\n";
+		print 'Getting '
+		  . $self->{'_applianceurlbase'}
+		  . $_URL{'sysinfo'} . "\n";
 	}
 	if (!defined($self->{'_lwpua'})) {
 		$self->_create_ua();
 	}
-	my $request = HTTP::Request->new('GET', $self->{'_applianceurlbase'} . $_URL{'sysinfo'});
-	$request->authorization_basic($self->{'_applianceusername'}, $self->{'_appliancepassword'});
+	my $request =
+	  HTTP::Request->new('GET',
+		$self->{'_applianceurlbase'} . $_URL{'sysinfo'});
+	$request->authorization_basic($self->{'_applianceusername'},
+		$self->{'_appliancepassword'});
 	my $response = $self->{'_lwpua'}->request($request);
 
 	if ($response->is_error) {
-		return undef;
+		return 0;
 	}
 	else {
 		$self->{'sgos_sysinfo'} = $response->content;
@@ -172,7 +184,7 @@ sub get_sysinfo {
 		return 1;
 	}
 	else {
-		return undef;
+		return 0;
 	}
 }
 
@@ -192,27 +204,27 @@ sub get_sysinfo_from_file {
 		print "sub:get_sysinfo_from_file, filename=$filename\n";
 	}
 	if (-f $filename) {
-		open(FSDFLKFJ, '<' . $filename);
+		open my $FSDFLKFJ, q{<} , $filename;
 
 		# slurp
 		{
 			local $/ = undef;
-			$self->{'sgos_sysinfo'} = <FSDFLKFJ>;
+			$self->{'sgos_sysinfo'} = <$FSDFLKFJ>;
 			$self->{'sgos_sysinfo'} =~ s/\r\n/\n/gi;
 		}
-		close FSDFLKFJ;
+		close $FSDFLKFJ;
 
 		if ($self->{'sgos_sysinfo'}) {
 			return 1;
 		}
 		else {
-			return undef;
+			return 0;
 		}
 	}
 	else {
 
 		# no filename specified
-		return undef;
+		return 0;
 	}
 }
 
@@ -237,7 +249,7 @@ sub get_sysinfo_from_data {
 		return 1;
 	}
 	else {
-		return undef;
+		return 0;
 	}
 }
 
@@ -254,7 +266,10 @@ sub parse_sysinfo {
 		print "parse_sysinfo\n";
 	}
 	my @split_sysinfo =
-	  split(/__________________________________________________________________________/, $self->{'sgos_sysinfo'});
+	  split(
+/__________________________________________________________________________/,
+		$self->{'sgos_sysinfo'}
+	  );
 	$self->{'_sgos_sysinfo_split_count'} = $#split_sysinfo;
 
 	# init the % var
@@ -267,7 +282,8 @@ sub parse_sysinfo {
 	# Version 6.0
 	# Version 6.1
 	# Version 7.0
-	($self->{'_sysinfoversion'}) = $self->{'sgos_sysinfo_sect'}{'_ReportInfo'} =~ m/Version (\d+\.\d+)/;
+	($self->{'_sysinfoversion'}) =
+	  $self->{'sgos_sysinfo_sect'}{'_ReportInfo'} =~ m/Version (\d+\.\d+)/;
 
 	# Loop through each section of the split sysinfo
 	foreach (1 .. $#split_sysinfo) {
@@ -367,9 +383,10 @@ sub _parse_appliance_name {
 	}
 	if (defined($self->{'sgos_sysinfo_sect'}{'Software Configuration'})) {
 		(undef, $self->{'appliance-name'}) =
-		  $self->{'sgos_sysinfo_sect'}{'Software Configuration'} =~ m/(appliance-name|hostname) (.+)$/im;
-		$self->{'appliance-name'}                                =~ s/^\"//;
-		$self->{'appliance-name'}                                =~ s/\"$//;
+		  $self->{'sgos_sysinfo_sect'}{'Software Configuration'} =~
+		  m/(appliance-name|hostname) (.+)$/im;
+		$self->{'appliance-name'} =~ s/^\"//;
+		$self->{'appliance-name'} =~ s/\"$//;
 
 		if ($self->{'_debuglevel'} > 0) {
 			print "appliancename=$self->{'appliance-name'}\n";
@@ -388,7 +405,9 @@ sub _parse_model_number {
 	#210-5 (unsupported configuration)
 	#
 	if (defined($self->{'sgos_sysinfo_sect'}{'Hardware Information'})) {
-		($self->{'modelnumber'}) = $self->{'sgos_sysinfo_sect'}{'Hardware Information'} =~ m/Model:\s(.+)/im;
+		($self->{'modelnumber'}) =
+		  $self->{'sgos_sysinfo_sect'}{'Hardware Information'} =~
+		  m/Model:\s(.+)/im;
 		if ($self->{'modelnumber'} =~ m/unsupported configuration/i) {
 			$self->{'modelnumber'} =~ s/\s*\(unsupported configuration\)\s*//ig;
 			$self->{'supported_configuration'} = 0;
@@ -409,7 +428,9 @@ sub _parse_network {
 		print "_parse_network\n";
 	}
 	if (defined($self->{'sgos_sysinfo_sect'}{'Hardware Information'})) {
-		my ($netinfo) = $self->{'sgos_sysinfo_sect'}{'Hardware Information'} =~ m/Network:(.+)Accelerators/ism;
+		my ($netinfo) =
+		  $self->{'sgos_sysinfo_sect'}{'Hardware Information'} =~
+		  m/Network:(.+)Accelerators/ism;
 		my @s = split(/\n/, $netinfo);
 		chomp @s;
 		foreach (@s) {
@@ -419,19 +440,22 @@ sub _parse_network {
 			my ($running)   = $line =~ m/running\sat\s(.+)\s\(MAC/im;
 			my $capabilities;
 
-			#Interface 0:0: Intel Gigabit     running at 1 Gbps full duplex (MAC 00:e0:81:79:a5:1a)
-			#Interface 2:0: Bypass 10/100/1000 with no link  (MAC 00:e0:ed:0b:67:e6)
+#Interface 0:0: Intel Gigabit     running at 1 Gbps full duplex (MAC 00:e0:81:79:a5:1a)
+#Interface 2:0: Bypass 10/100/1000 with no link  (MAC 00:e0:ed:0b:67:e6)
 			if ($line =~ m/running at/) {
-				($capabilities) = $line =~ m/Interface\s$interface\:\s\w+(.+)\s+running at/;
+				($capabilities) =
+				  $line =~ m/Interface\s$interface\:\s\w+(.+)\s+running at/;
 			}
 			if ($line =~ m/with no link/) {
-				($capabilities) = $line =~ m/Interface\s$interface\:\s\w+(.+)\s+with no link/;
+				($capabilities) =
+				  $line =~ m/Interface\s$interface\:\s\w+(.+)\s+with no link/;
 			}
 			if ($capabilities) {
 				$capabilities =~ s/\s+//ig;
 			}
 			if ($interface && $capabilities) {
-				$self->{'interface'}{$interface}{'capabilities'} = $capabilities;
+				$self->{'interface'}{$interface}{'capabilities'} =
+				  $capabilities;
 			}
 
 			#print "Running=$running\n";
@@ -462,7 +486,8 @@ sub _parse_network {
 	if (defined($self->{'sgos_sysinfo_sect'}{'Software Configuration'})) {
 		if ($#t < 2) {
 			@t =
-			  split(/\n/, $self->{'sgos_sysinfo_sect'}{'Software Configuration'});
+			  split(/\n/,
+				$self->{'sgos_sysinfo_sect'}{'Software Configuration'});
 		}
 	}
 
@@ -481,7 +506,8 @@ sub _parse_network {
 		if ($line =~ m/ip-address/) {
 
 			($ip, $netmask) =
-			  $line =~ m/^ip-address\s*(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) *(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})*/i;
+			  $line =~
+m/^ip-address\s*(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) *(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})*/i;
 			if (defined($ip)) {
 				$ip =~ s/\s+//gi;
 			}
@@ -490,17 +516,18 @@ sub _parse_network {
 			}
 		}
 		if ($line =~ m/subnet-mask/) {
-			($netmask) = $line =~ m/^subnet-mask *(.{1,3}\..{1,3}\..{1,3}\..{1,3})/i;
+			($netmask) =
+			  $line =~ m/^subnet-mask *(.{1,3}\..{1,3}\..{1,3}\..{1,3})/i;
 			$netmask =~ s/\s+//gi;
 		}
 
-		if (defined($interface) ) {
+		if (defined($interface)) {
 			if (length($interface) > 1 && $ip && $netmask) {
-			$self->{'interface'}{$interface}{'ip'}      = $ip;
-			$self->{'interface'}{$interface}{'netmask'} = $netmask;
-			$interface                                  = undef;
-			$ip                                         = undef;
-		}
+				$self->{'interface'}{$interface}{'ip'}      = $ip;
+				$self->{'interface'}{$interface}{'netmask'} = $netmask;
+				$interface                                  = undef;
+				$ip                                         = undef;
+			}
 		}
 
 	}
@@ -527,7 +554,8 @@ sub _parse_swconfig {
 		}
 		else {
 			if (defined($self->{'sgos_swconfig_section'}{$sectionname})) {
-				$self->{'sgos_swconfig_section'}{$sectionname} = $self->{'sgos_swconfig_section'}{$sectionname} . $line . "\n";
+				$self->{'sgos_swconfig_section'}{$sectionname} =
+				  $self->{'sgos_swconfig_section'}{$sectionname} . $line . "\n";
 			}
 			else {
 				$self->{'sgos_swconfig_section'}{$sectionname} = $line . "\n";
@@ -555,7 +583,8 @@ sub _parse_static_bypass {
 				else {
 					$line =~ s/^add //i;
 					if (defined($self->{'static-bypass'})) {
-						$self->{'static-bypass'} = $self->{'static-bypass'} . $line . "\n";
+						$self->{'static-bypass'} =
+						  $self->{'static-bypass'} . $line . "\n";
 					}
 					else {
 						$self->{'static-bypass'} = $line . "\n";
@@ -576,7 +605,8 @@ sub _parse_vpm {
 
 		foreach my $line (@lines) {
 			if ($line =~ m/^inline policy vpm-cpl \"*end-(\d+)-inline\"*/) {
-				($have_vpm_cpl) = $line =~ m/^inline policy vpm-cpl \"*end-(\d+)-inline\"*/;
+				($have_vpm_cpl) =
+				  $line =~ m/^inline policy vpm-cpl \"*end-(\d+)-inline\"*/;
 			}
 			elsif ($have_vpm_cpl) {
 				if ($line =~ m/end-$have_vpm_cpl-inline/i) {
@@ -596,7 +626,8 @@ sub _parse_vpm {
 
 		foreach my $line (@lines) {
 			if ($line =~ m/^inline policy vpm-xml \"*end-(\d+)-inline\"*/) {
-				($have_vpm_xml) = $line =~ m/^inline policy vpm-xml \"*end-(\d+)-inline\"*/;
+				($have_vpm_xml) =
+				  $line =~ m/^inline policy vpm-xml \"*end-(\d+)-inline\"*/;
 			}
 			elsif ($have_vpm_xml) {
 				if ($line =~ m/end-$have_vpm_xml-inline/i) {
@@ -654,13 +685,15 @@ sub _parse_default_gateway {
 	if (defined($self->{'sgos_sysinfo_sect'}{'Software Configuration'})) {
 		if ($#s < 2) {
 			@s =
-			  split(/\n/, $self->{'sgos_sysinfo_sect'}{'Software Configuration'});
+			  split(/\n/,
+				$self->{'sgos_sysinfo_sect'}{'Software Configuration'});
 		}
 	}
 	if ($#s > 0) {
 		foreach my $line (@s) {
 			if ($line =~ m/ip-default-gateway/) {
-				($self->{'ip-default-gateway'}) = $line =~ m/^ip-default-gateway +(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/;
+				($self->{'ip-default-gateway'}) = $line =~
+				  m/^ip-default-gateway +(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/;
 			}
 		}
 	}
@@ -680,16 +713,19 @@ sub _parse_route_table {
 	if (defined($self->{'sgos_sysinfo_sect'}{'TCP/IP Routing Table'})) {
 		my @r;
 		if ($self->{'sgos_sysinfo_sect'}{'TCP/IP Routing Table'}) {
-			$self->{'routetable'} = $self->{'sgos_sysinfo_sect'}{'TCP/IP Routing Table'};
+			$self->{'routetable'} =
+			  $self->{'sgos_sysinfo_sect'}{'TCP/IP Routing Table'};
 		}
 		else {
 			@r =
-			  split(/\n/, $self->{'sgos_sysinfo_sect'}{'Software Configuration'});
+			  split(/\n/,
+				$self->{'sgos_sysinfo_sect'}{'Software Configuration'});
 		}
 		my $marker;
 		foreach my $line (@r) {
 			if ($line =~ m/inline static-route-table \"end-\d+-inline\"/i) {
-				($marker) = $line =~ m/inline static-route-table \"end-(\d+)-inline\"/i;
+				($marker) =
+				  $line =~ m/inline static-route-table \"end-(\d+)-inline\"/i;
 			}
 			if ($self->{'_debuglevel'} > 0) {
 				print "_parse_route_table: marker=$marker\n";
@@ -707,7 +743,8 @@ sub _parse_route_table {
 m/\s*(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\s*(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\s*(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/
 				  ) {
 					if (defined($self->{'static-route-table'})) {
-						$self->{'static-route-table'} = $self->{'static-route-table'} . $line . "\n";
+						$self->{'static-route-table'} =
+						  $self->{'static-route-table'} . $line . "\n";
 					}
 					else {
 						$self->{'static-route-table'} = $line . "\n";
@@ -726,7 +763,9 @@ sub _parse_serial_number {
 		print "_parse_sgos_serial_number\n";
 	}
 	if (defined($self->{'sgos_sysinfo_sect'}{'Version Information'})) {
-		($self->{'serialnumber'}) = $self->{'sgos_sysinfo_sect'}{'Version Information'} =~ m/Serial\snumber\sis\s(\d+)/isx;
+		($self->{'serialnumber'}) =
+		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~
+		  m/Serial\snumber\sis\s(\d+)/isx;
 	}
 }
 
@@ -746,7 +785,9 @@ sub _parse_ssl_accelerator {
 	#  Internal: Broadcom 5825 Security Processor
 	#
 	if (defined($self->{'sgos_sysinfo_sect'}{'Hardware Information'})) {
-		my ($acceleratorinfo) = $self->{'sgos_sysinfo_sect'}{'Hardware Information'} =~ m/(Accelerators\:.+)/ism;
+		my ($acceleratorinfo) =
+		  $self->{'sgos_sysinfo_sect'}{'Hardware Information'} =~
+		  m/(Accelerators\:.+)/ism;
 		my @a = split(/\n/, $acceleratorinfo);
 
 		#print "There are $#a lines\n";
@@ -773,7 +814,9 @@ sub _parse_sysinfo_time {
 		print "_parse_sysinfo_time\n";
 	}
 	if (defined($self->{'sgos_sysinfo_sect'}{'Version Information'})) {
-		($self->{'sysinfotime'}) = $self->{'sgos_sysinfo_sect'}{'Version Information'} =~ m/^The current time is (.+) \(/im;
+		($self->{'sysinfotime'}) =
+		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~
+		  m/^The current time is (.+) \(/im;
 		$self->{'sysinfotime_epoch'} = str2time($self->{'sysinfotime'});
 	}
 }
@@ -784,24 +827,29 @@ sub _parse_reboot_time {
 		print "_parse_reboot_time\n";
 	}
 
-	# Calculate hardware reboot time
-	# The ProxySG Appliance was last hardware rebooted 1 days, 5 hours, 55 minutes, and 0 seconds ago.
+# Calculate hardware reboot time
+# The ProxySG Appliance was last hardware rebooted 1 days, 5 hours, 55 minutes, and 0 seconds ago.
 	if (defined($self->{'sgos_sysinfo_sect'}{'Version Information'})) {
 		($self->{'hardware_reboot'}) =
-		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~ m/The ProxySG Appliance was last hardware rebooted (.*)$/m;
-		($self->{'hardware_reboot_day'}) = $self->{'hardware_reboot'} =~ m/(\d+) day/;
+		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~
+		  m/The ProxySG Appliance was last hardware rebooted (.*)$/m;
+		($self->{'hardware_reboot_day'}) =
+		  $self->{'hardware_reboot'} =~ m/(\d+) day/;
 		if (!defined($self->{'hardware_reboot_day'})) {
 			$self->{'hardware_reboot_day'} = 0;
 		}
-		($self->{'hardware_reboot_hour'}) = $self->{'hardware_reboot'} =~ m/(\d+) hour/;
+		($self->{'hardware_reboot_hour'}) =
+		  $self->{'hardware_reboot'} =~ m/(\d+) hour/;
 		if (!defined($self->{'hardware_reboot_hour'})) {
 			$self->{'hardware_reboot_hour'} = 0;
 		}
-		($self->{'hardware_reboot_minute'}) = $self->{'hardware_reboot'} =~ m/(\d+) minute/;
+		($self->{'hardware_reboot_minute'}) =
+		  $self->{'hardware_reboot'} =~ m/(\d+) minute/;
 		if (!defined($self->{'hardware_reboot_minute'})) {
 			$self->{'hardware_reboot_minute'} = 0;
 		}
-		($self->{'hardware_reboot_second'}) = $self->{'hardware_reboot'} =~ m/(\d+) second/;
+		($self->{'hardware_reboot_second'}) =
+		  $self->{'hardware_reboot'} =~ m/(\d+) second/;
 		if (!defined($self->{'hardware_reboot_second'})) {
 			$self->{'hardware_reboot_second'} = 0;
 		}
@@ -811,23 +859,28 @@ sub _parse_reboot_time {
 		  ($self->{'hardware_reboot_minute'} * 60) +
 		  $self->{'hardware_reboot_second'};
 
-		# The ProxySG Appliance was last software rebooted 1 days, 5 hours, 55 minutes, and 1 seconds ago.
+# The ProxySG Appliance was last software rebooted 1 days, 5 hours, 55 minutes, and 1 seconds ago.
 
 		($self->{'software_reboot'}) =
-		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~ m/The ProxySG Appliance was last software rebooted (.*)$/m;
-		($self->{'software_reboot_day'}) = $self->{'software_reboot'} =~ m/(\d+) day/;
+		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~
+		  m/The ProxySG Appliance was last software rebooted (.*)$/m;
+		($self->{'software_reboot_day'}) =
+		  $self->{'software_reboot'} =~ m/(\d+) day/;
 		if (!defined($self->{'software_reboot_day'})) {
 			$self->{'software_reboot_day'} = 0;
 		}
-		($self->{'software_reboot_hour'}) = $self->{'software_reboot'} =~ m/(\d+) hour/;
+		($self->{'software_reboot_hour'}) =
+		  $self->{'software_reboot'} =~ m/(\d+) hour/;
 		if (!defined($self->{'software_reboot_hour'})) {
 			$self->{'software_reboot_hour'} = 0;
 		}
-		($self->{'software_reboot_minute'}) = $self->{'software_reboot'} =~ m/(\d+) minute/;
+		($self->{'software_reboot_minute'}) =
+		  $self->{'software_reboot'} =~ m/(\d+) minute/;
 		if (!defined($self->{'software_reboot_minute'})) {
 			$self->{'software_reboot_minute'} = 0;
 		}
-		($self->{'software_reboot_second'}) = $self->{'software_reboot'} =~ m/(\d+) second/;
+		($self->{'software_reboot_second'}) =
+		  $self->{'software_reboot'} =~ m/(\d+) second/;
 		if (!defined($self->{'software_reboot_second'})) {
 			$self->{'software_reboot_second'} = 0;
 		}
@@ -848,7 +901,9 @@ sub _parse_sgos_releaseid {
 	# parse  SGOS version, SGOS releaseid, and serial number
 	# SGOS release ID
 	if (defined($self->{'sgos_sysinfo_sect'}{'Version Information'})) {
-		($self->{'sgosreleaseid'}) = $self->{'sgos_sysinfo_sect'}{'Version Information'} =~ m/Release\sid:\s(\d+)/isx;
+		($self->{'sgosreleaseid'}) =
+		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~
+		  m/Release\sid:\s(\d+)/isx;
 	}
 }
 
@@ -871,7 +926,9 @@ sub _parse_sgos_version {
 	# Version: SGOS 4.2.10.1
 	#
 	if (defined($self->{'sgos_sysinfo_sect'}{'Version Information'})) {
-		($self->{'sgosversion'}) = $self->{'sgos_sysinfo_sect'}{'Version Information'} =~ m/Version:\sSGOS\s(\d+\.\d+\.\d+\.\d+)/im;
+		($self->{'sgosversion'}) =
+		  $self->{'sgos_sysinfo_sect'}{'Version Information'} =~
+		  m/Version:\sSGOS\s(\d+\.\d+\.\d+\.\d+)/im;
 		if ($self->{'_debuglevel'} > 0) {
 			print "SGOS version = $self->{'sgosversion'}\n";
 		}
@@ -906,7 +963,8 @@ sub send_command {
 	my $request = POST $self->{'_applianceurlbase'} . $_URL{'send_command'},
 	  Content_Type => 'form-data',
 	  'Content'    => ['file' => $command];
-	$request->authorization_basic($self->{'_applianceusername'}, $self->{'_appliancepassword'});
+	$request->authorization_basic($self->{'_applianceusername'},
+		$self->{'_appliancepassword'});
 	my $response = $self->{'_lwpua'}->request($request);
 	my $content;
 	if ($response->is_success) {
